@@ -12,12 +12,12 @@ import numpy as np
 from collections import MutableSequence
 from genx.gui_logging import iprint
 
-
 class Parameter(object):
     """Base class for all Parameters"""
+
     def __init__(self, help="", unit=""):
-        self.help = help
-        self.unit = unit
+        self.help=help
+        self.unit=unit
 
     def _get_value(self, **kwargs):
         raise NotImplementedError("Callback parameter method not implemented")
@@ -54,17 +54,17 @@ class ArithmeticParameter(Parameter):
     def _check_obj(self, other):
         """ Checks the object other so that it fulfills the demands for arithmetic operations.
         """
-        supported_types = [int, float, int, complex, np.float64, np.float32]
+        supported_types=[int, float, int, complex, np.float64, np.float32]
         if is_parameter(other):
             pass
         elif not type(other) in supported_types:
-            raise TypeError("%s is not supported for arithmetic operations "% (repr(type(other))) +
+            raise TypeError("%s is not supported for arithmetic operations "%(repr(type(other)))+
                             "of a Parameter. It has to be int, float, long or complex")
 
     def _new_object_from_func(self, value_func, help=""):
         """Create a new object from function"""
-        new = ArithmeticParameter(help=help)
-        new._get_value = value_func
+        new=ArithmeticParameter(help=help)
+        new._get_value=value_func
         return new
 
     def __mul__(self, other):
@@ -91,40 +91,40 @@ class ArithmeticParameter(Parameter):
         self._check_obj(other)
         if is_parameter(other):
             def new_func(**kwargs):
-                return self(**kwargs) + other(**kwargs)
+                return self(**kwargs)+other(**kwargs)
         else:
             def new_func(**kwargs):
-                return self(**kwargs) + other
+                return self(**kwargs)+other
         return self._new_object_from_func(new_func)
 
     def __radd__(self, other):
         self._check_obj(other)
         if is_parameter(other):
             def new_func(**kwargs):
-                return other(**kwargs) + self(**kwargs)
+                return other(**kwargs)+self(**kwargs)
         else:
             def new_func(**kwargs):
-                return other + self(**kwargs)
+                return other+self(**kwargs)
         return self._new_object_from_func(new_func)
 
     def __sub__(self, other):
         self._check_obj(other)
         if is_parameter(other):
             def new_func(**kwargs):
-                return self(**kwargs) - other(**kwargs)
+                return self(**kwargs)-other(**kwargs)
         else:
             def new_func(**kwargs):
-                return self(**kwargs) - other
+                return self(**kwargs)-other
         return self._new_object_from_func(new_func)
 
     def __rsub__(self, other):
         self._check_obj(other)
         if is_parameter(other):
             def new_func(**kwargs):
-                return other(**kwargs) - self(**kwargs)
+                return other(**kwargs)-self(**kwargs)
         else:
             def new_func(**kwargs):
-                return other - self(**kwargs)
+                return other-self(**kwargs)
         return self._new_object_from_func(new_func)
 
     def __div__(self, other):
@@ -150,11 +150,13 @@ class ArithmeticParameter(Parameter):
     def __neg__(self):
         def new_func(**kwargs):
             return -self(**kwargs)
+
         return self._new_object_from_func(new_func)
 
     def __pos__(self):
         def new_func(**kwargs):
             return self(**kwargs)
+
         return self._new_object_from_func(new_func)
 
     def __pow__(self, other):
@@ -177,21 +179,21 @@ class ArithmeticParameter(Parameter):
                 return other**self(**kwargs)
         return self._new_object_from_func(new_func)
 
-
 class NumericParameter(ArithmeticParameter):
     """A parameter holding a numeric value"""
+
     def __init__(self, value, help="", unit=""):
         ArithmeticParameter.__init__(self, help, unit=unit)
-        self.value = value
-        self._coupled_parameter = None
+        self.value=value
+        self._coupled_parameter=None
 
     def validate(self, value):
         raise NotImplementedError("Validation of value not implemented")
 
     def __setattr__(self, key, value):
-        if key == 'value':
+        if key=='value':
             object.__setattr__(self, 'value', self.validate(value))
-            self._coupled_parameter = None
+            self._coupled_parameter=None
         else:
             object.__setattr__(self, key, value)
 
@@ -210,16 +212,18 @@ class NumericParameter(ArithmeticParameter):
         """Returns True if the parameter is coupled to another parameter."""
         return self._coupled_parameter is not None
 
-
 class Enum(Parameter):
     """An enumeration object"""
-    def __init__(self, allowed_values=[], help=""):
+
+    def __init__(self, allowed_values=None, help=""):
         Parameter.__init__(self, help=help)
-        self.allowed_values = allowed_values
-        self.value = self.allowed_values[0]
+        if allowed_values is None:
+            allowed_values=[]
+        self.allowed_values=allowed_values
+        self.value=self.allowed_values[0]
 
     def __setattr__(self, key, value):
-        if key == 'value':
+        if key=='value':
             object.__setattr__(self, 'value', self.validate(value))
         else:
             object.__setattr__(self, key, value)
@@ -229,30 +233,31 @@ class Enum(Parameter):
         if value in self.allowed_values:
             return value
         elif isinstance(value, int):
-            if len(self.allowed_values) > value > 0:
+            if len(self.allowed_values)>value>0:
                 return self.allowed_values[0]
         raise ValueError("The value to an enum must be either an integer"
-                         " between 0 and %d or one of %s" % (len(self.allowed_values), str(self.allowed_values)))
+                         " between 0 and %d or one of %s"%(len(self.allowed_values), str(self.allowed_values)))
 
     def _get_value(self, **kwargs):
         return self.value
 
-
 class List(MutableSequence):
     """A List object with type checking"""
-    protected = True
+    protected=True
 
-    def __init__(self, allowed_type=None, value=[], help=""):
-        self.help = help
-        self.allowed_type = allowed_type
-        self.data = list()
+    def __init__(self, allowed_type=None, value=None, help=""):
+        if value is None:
+            value=[]
+        self.help=help
+        self.allowed_type=allowed_type
+        self.data=list()
         for item in value:
             self._check(item)
             self.data.append(item)
 
     def _check(self, value):
         if self.allowed_type is not None and not isinstance(value, self.allowed_type):
-            raise ValueError("List object can only consist of type %s, trying to set a type: %s" %
+            raise ValueError("List object can only consist of type %s, trying to set a type: %s"%
                              (self.allowed_type, type(value)))
 
     def validate(self, value):
@@ -263,7 +268,7 @@ class List(MutableSequence):
         return self.data[item]
 
     def __setitem__(self, key, value):
-        #print "Setting ", key, " to ", value
+        # print "Setting ", key, " to ", value
         if isinstance(key, slice):
             for item in value:
                 self._check(item)
@@ -281,7 +286,6 @@ class List(MutableSequence):
         self._check(value)
         self.data.insert(index, value)
 
-
 class HasParameters(object):
     """Mixin class to handle the setting of parameters in a correct manner.
 
@@ -290,7 +294,7 @@ class HasParameters(object):
 
     Also if an attribute implements a boolean attribute protected which is True then this attribute can not be set.
     """
-    validation_kwargs = {}
+    validation_kwargs={}
 
     def __init__(self, **kwargs):
         """The given allowed keyword arguments allow to initialise parameters"""
@@ -298,12 +302,12 @@ class HasParameters(object):
             if hasattr(self, name):
                 self.__setattr__(name, kwargs[name])
             else:
-                raise TypeError("Creation of %s got an unexpected keyword argument %s" %
+                raise TypeError("Creation of %s got an unexpected keyword argument %s"%
                                 (self.__class__.__name__, name))
 
     def __setattr__(self, name, value):
         try:
-            attr = self.__getattribute__(name)
+            attr=self.__getattribute__(name)
         except AttributeError:
             # Attribute does not exist
             object.__setattr__(self, name, value)
@@ -315,17 +319,17 @@ class HasParameters(object):
                     try:
                         attr.validate(value(parameter=name, **self.validation_kwargs.copy()))
                     except ValueError as e:
-                        raise ValueError('Can not set attribute %s. %s' % (name, str(e)))
+                        raise ValueError('Can not set attribute %s. %s'%(name, str(e)))
                     else:
-                        #print "Coupling parameter: %s" % name
+                        # print "Coupling parameter: %s" % name
                         attr.couple_parameter(value)
                 elif isinstance(attr, NumericParameter):
-                    attr.value = value
+                    attr.value=value
                 else:
-                    raise AttributeError("Setting attribute %s is not allowed"% name)
+                    raise AttributeError("Setting attribute %s is not allowed"%name)
             else:
                 if self._is_protected(attr):
-                    raise AttributeError("Setting attribute %s is not allowed" % name)
+                    raise AttributeError("Setting attribute %s is not allowed"%name)
                 else:
                     object.__setattr__(self, name, value)
 
@@ -341,13 +345,12 @@ class HasParameters(object):
 
         return self.__getattribute__(kwargs['parameter'])(**kwargs)
 
-
     def _is_protected(self, attr):
         """Check if an attribute is marked as protected (implements variable protected and set to True)"""
         try:
-            protected = attr.__getattribute__("protected")
+            protected=attr.__getattribute__("protected")
         except AttributeError:
-            protected = False
+            protected=False
         return protected
 
     def get_parameter_list(self, numeric_types_only=False):
@@ -362,29 +365,29 @@ class HasParameters(object):
         Returns:
             par_list (list): A list of strings with names of all the parameters.
         """
-        allowed_parameter_classes = NumericParameter if numeric_types_only else Parameter
+        allowed_parameter_classes=NumericParameter if numeric_types_only else Parameter
         # Loop thorough all member objects to find the allowed parameters.
         #  Note that if it is not included if it inherits HasParameters or beginning with a _
-        members = self.__dict__
-        par_list = [name for name in members
-                    if isinstance(members[name], allowed_parameter_classes)
-                    and not isinstance(members[name], HasParameters) and name[0] != '_'
-         ]
+        members=self.__dict__
+        par_list=[name for name in members
+                  if isinstance(members[name], allowed_parameter_classes)
+                  and not isinstance(members[name], HasParameters) and name[0]!='_'
+                  ]
         # Loop through all the objects that inherit from HasParameter classes and add the full parameter name
-        [[par_list.append(name + par_name) for par_name in
+        [[par_list.append(name+par_name) for par_name in
           members[name].get_parameter_list(numeric_types_only=numeric_types_only)
           ]
          for name in members if isinstance(members[name], HasParameters)
          ]
         return par_list
 
-
 class Var(ArithmeticParameter):
     """ A model specific variable that will be included in the arguments to the evaluation."""
+
     def __init__(self, name, default_val, help=""):
         ArithmeticParameter.__init__(self, help)
-        self.name = name
-        self.default_val = default_val
+        self.name=name
+        self.default_val=default_val
 
     def _get_value(self, **kwargs):
         try:
@@ -392,85 +395,85 @@ class Var(ArithmeticParameter):
         except KeyError:
             return self.default_val
 
-
 class Calc(ArithmeticParameter):
     """A calculation done by a function of kwargs that is used as a parameter"""
+
     def __init__(self, function, help=""):
         ArithmeticParameter.__init__(self, help)
-        self.function = function
+        self.function=function
 
     def _get_value(self, **kwargs):
         return self.function(**kwargs)
 
-
 class Func(Calc, HasParameters):
     """ Simulates a function of parameters"""
+
     def __init__(self, **kwargs):
         HasParameters.__init__(self, **kwargs)
 
     def function(self, **kwargs):
         raise NotImplementedError("Method function in Func object not implemented.")
 
-
 class Wrap(object):
     """ Defines a function where the argument can consist of parameters."""
+
     def __init__(self, function):
-        self.function = function
+        self.function=function
 
     def __call__(self, *args):
         def wrap(**kwargs):
-            new_args = []
+            new_args=[]
             for arg in args:
                 if is_parameter(arg):
                     new_args.append(arg(**kwargs))
                 else:
                     new_args.append(arg)
             return self.function(*new_args)
-        wrap.__name__ = self.function.__name__
+
+        wrap.__name__=self.function.__name__
 
         return Calc(wrap, help=wrap.__name__)
 
-
 class Int(NumericParameter):
     """An integer parameter"""
+
     def validate(self, value):
         try:
-            value = int(value)
+            value=int(value)
         except Exception:
-            raise ValueError('%s can not be cast to int' % value.__repr__())
+            raise ValueError('%s can not be cast to int'%value.__repr__())
         return value
 
-
 class Float(NumericParameter):
     """An floating point parameter"""
+
     def validate(self, value):
         try:
-            value = float(value)
+            value=float(value)
         except Exception:
-            raise ValueError('%s can not be cast to float' % value.__repr__())
+            raise ValueError('%s can not be cast to float'%value.__repr__())
         return value
 
-
 class Complex(NumericParameter, HasParameters):
     """A complex number parameter"""
 
     def __init__(self, value, **kwargs):
-        self.real = Float(0)
-        self.imag = Float(0)
+        self.real=Float(0)
+        self.imag=Float(0)
         NumericParameter.__init__(self, value, **kwargs)
 
     def validate(self, value):
         try:
-            value = complex(value)
+            value=complex(value)
         except Exception:
-            raise ValueError('%s can not be cast to complex' % value.__repr__())
+            raise ValueError('%s can not be cast to complex'%value.__repr__())
         return value
 
     def __setattr__(self, key, value):
-        if key == 'value':
-            value = self.validate(value)
-            self.real.value = value.real
-            self.imag.value = value.imag
+        if key=='value':
+            value=self.validate(value)
+            self.real.value=value.real
+            self.imag.value=value.imag
         else:
             HasParameters.__setattr__(self, key, value)
 
@@ -479,31 +482,30 @@ class Complex(NumericParameter, HasParameters):
         if self.has_coupled_parameter():
             return self.validate(self._coupled_parameter(**kwargs))
         else:
-            return self.real(**kwargs) + 1.0J*self.imag(**kwargs)
-
+            return self.real(**kwargs)+1.0J*self.imag(**kwargs)
 
 class FloatArray(NumericParameter):
     """A float array parameter"""
+
     # TODO: Add an array interface to support slicing as well...
     def validate(self, value):
         try:
-            value = np.array(value, dtype=np.float64)
+            value=np.array(value, dtype=np.float64)
         except Exception:
-            raise ValueError('%s can not be cast to float' % value.__repr__())
+            raise ValueError('%s can not be cast to float'%value.__repr__())
         return value
 
-
 class ComplexArray(Complex):
     # TODO: Add an array interface to support slicing as well...
     """A complex array parameter"""
+
     def validate(self, value):
         try:
-            value = np.array(value, dtype=np.complex128)
+            value=np.array(value, dtype=np.complex128)
         except Exception:
-            raise ValueError('%s can not be cast to complex array' % value.__repr__())
+            raise ValueError('%s can not be cast to complex array'%value.__repr__())
         return value
 
-
 def get_parameters(obj, numeric_types_only=False, group_parameters=True):
     """Searches obj for members that are inherited from Parameters or HasParameters and places them in a dictonary.
 
@@ -515,30 +517,30 @@ def get_parameters(obj, numeric_types_only=False, group_parameters=True):
     Returns:
         par_dict (dict): A Dictonary with class names as keys and items as lists of parameter names.
     """
-    par_dict = {}
+    par_dict={}
 
     def add_parameter_to_dict(d, key, item):
         try:
             d[key].append(item)
         except KeyError:
-            d[key] = [item]
+            d[key]=[item]
 
     def add_object_to_dict(d, cls, name, object):
         try:
-            dcls = d[cls]
+            dcls=d[cls]
         except KeyError:
-            d[cls] = {}
-            dcls = d[cls]
+            d[cls]={}
+            dcls=d[cls]
 
-        dcls[name] = object
+        dcls[name]=object
 
-    members = obj.__dict__
-    allowed_parameter_classes = NumericParameter if numeric_types_only else Parameter
+    members=obj.__dict__
+    allowed_parameter_classes=NumericParameter if numeric_types_only else Parameter
     # Loop thorough all member objects to find the allowed parameters. Note that if it is not included if it inherits
     # HasParameters
     [add_parameter_to_dict(par_dict, members[name].__class__.__name__, name)
      for name in members
-     if name[0] != '_' and
+     if name[0]!='_' and
      isinstance(members[name], allowed_parameter_classes) and
      not isinstance(members[name], HasParameters)
      ]
@@ -551,37 +553,38 @@ def get_parameters(obj, numeric_types_only=False, group_parameters=True):
      ]
     return par_dict
 
-
-if __name__ == '__main__':
+if __name__=='__main__':
     import numpy as np
-    exp = Wrap(np.exp)
 
-    p = Int(10)
-    r = FloatArray(33.333)
-    q = p**2 + r
+    exp=Wrap(np.exp)
+
+    p=Int(10)
+    r=FloatArray(33.333)
+    q=p**2+r
     iprint(p.has_coupled_parameter())
     iprint(p())
-    r.value = 0.0
+    r.value=0.0
     iprint(q())
-    c = Complex(1 + 1.0J)
-    c.real = q
-    phase = exp(c + 10)
+    c=Complex(1+1.0J)
+    c.real=q
+    phase=exp(c+10)
     iprint(phase())
-    r.value = 1.0
-    c.imag = 0.1
-    c.real = 5.0
+    r.value=1.0
+    c.imag=0.1
+    c.real=5.0
     iprint(c(), phase())
-    l = List(Int, [], help="Testing")
-    l[:] = [p, p]
+    l=List(Int, [], help="Testing")
+    l[:]=[p, p]
     iprint(type(l))
     iprint([item() for item in l])
-    obj = object()
+    obj=object()
     import new
-    test = new.module('test')
-    test.__dict__['c'] = c
-    test.__dict__['q'] = q
-    test.__dict__['p'] = p
-    test.__dict__['l'] = l
+
+    test=new.module('test')
+    test.__dict__['c']=c
+    test.__dict__['q']=q
+    test.__dict__['p']=p
+    test.__dict__['l']=l
     iprint(get_parameters(test, True))
     iprint(c.get_parameter_list())
     iprint(dir())
