@@ -119,6 +119,7 @@ from .lib import paratt as Paratt
 from .lib import neutron_refl as MatrixNeutron
 from .lib.instrument import *
 from .lib import refl as refl
+# from .lib.physical_constants import muB_to_SL
 
 # Preamble to define the parameters needed for the models outlined below:
 
@@ -329,14 +330,17 @@ def Specular(TwoThetaQz, sample, instrument):
             if Q_ok:
                 Q_ok=any(not_equal(Buffer.TwoThetaQz, Q))
         if Buffer.parameters!=parameters or not Q_ok:
-            # msld = 2.645e-5*magn*dens*instrument.getWavelength()**2/2/pi
-            np=1.0-l2pi*(sld+sld_m)
-            nm=1.0-l2pi*(sld-sld_m)
-            Vp=(2*pi/instrument.getWavelength())**2*(1-np**2)
-            Vm=(2*pi/instrument.getWavelength())**2*(1-nm**2)
+            # msld = muB_to_SL*magn*dens*instrument.getWavelength()**2/2/pi
+            if sld_m[-1]!=0. or sld[-1]!=0:
+                sld_m-=sld_m[-1]
+                sld-=sld[-1]
+            sld_p=l2pi*(sld+sld_m)
+            sld_m=l2pi*(sld-sld_m)
+            Vp=(2*pi/instrument.getWavelength())**2*(sld_p*(2.+sld_p))#(1-np**2) - better numerical accuracy
+            Vm=(2*pi/instrument.getWavelength())**2*(sld_m*(2.+sld_m))#(1-nm**2)
             (Ruu, Rdd, Rud, Rdu)=MatrixNeutron.Refl(Q, Vp, Vm, d, magn_ang, sigma)
-            Buffer.Ruu=Ruu;
-            Buffer.Rdd=Rdd;
+            Buffer.Ruu=Ruu
+            Buffer.Rdd=Rdd
             Buffer.Rud=Rud
             Buffer.parameters=parameters.copy()
             Buffer.TwoThetaQz=Q.copy()
@@ -412,7 +416,7 @@ def EnergySpecular(Energy, TwoThetaQz, sample, instrument):
     l2pi=wl**2/2/3.141592
     # Ordinary Paratt X-rays
     if type==instrument_string_choices['probe'][0] or type==0:
-        # R = Paratt.ReflQ(Q,instrument.getWavelength(),1.0-2.82e-5*sld,d,sigma)
+        # R = Paratt.ReflQ(Q,instrument.getWavelength(),1.0-r_e*sld,d,sigma)
         R=Paratt.Refl_nvary2(theta, wl, 1.0-l2pi*sld, d, sigma)
     else:
         raise ValueError('The choice of probe is WRONG')
