@@ -40,7 +40,7 @@ Stack
 ``Stack(Layers = [], Repetitions = 1)``
 
 ``Layers``
-   A ``list`` consiting of ``Layer``\ s in the stack the first item is
+   A ``list`` consiting of ``Layer``s in the stack the first item is
    the layer closest to the bottom
 ``Repetitions``
    The number of repsetions of the stack
@@ -50,7 +50,7 @@ Sample
 ``Sample(Stacks = [], Ambient = Layer(), Substrate = Layer())``
 
 ``Stacks``
-   A ``list`` consiting of ``Stack``\ s in the stacks the first item is
+   A ``list`` consiting of ``Stack``s in the stacks the first item is
    the layer closest to the bottom
 ``Ambient``
    A ``Layer`` describing the Ambient (enviroment above the sample).
@@ -127,14 +127,15 @@ from .lib import paratt as Paratt
 from .lib import neutron_refl as MatrixNeutron
 from .lib.instrument import *
 from .lib import refl as refl
+from .lib.physical_constants import r_e, muB_to_SL
 
 # Preamble to define the parameters needed for the models outlined below:
 
 # import lib.paratt as slow_paratt
 
 ModelID='SpecNX'
-# InstrumentParameters={'Wavelength':1.54, 'Coordinates':1, 'I0':1.0, 'Sim': 0,\
-#    'Res':0.001, 'Restype':0, 'Respoints':5, 'Resintrange':2, 'Beaw':0.01,\
+# InstrumentParameters={'Wavelength':1.54, 'Coordinates':1, 'I0':1.0, 'Sim': 0,
+#    'Res':0.001, 'Restype':0, 'Respoints':5, 'Resintrange':2, 'Beaw':0.01,
 #    'Footype':0.0, 'Samlen':10.0, 'Incangle':0.0}
 __pars__=['Layer', 'Stack', 'Sample', 'Instrument']
 
@@ -367,7 +368,7 @@ def specular_calcs(TwoThetaQz, sample, instrument, return_int=True):
         sld=neutron_sld(abs_xs, dens, fb, wl)
     # Ordinary Paratt X-rays
     if ptype==instrument_string_choices['probe'][0] or ptype==0:
-        R=Paratt.ReflQ(Q, instrument.getWavelength(), 1.0-2.82e-5*sld, d, sigma, return_int=return_int)
+        R=Paratt.ReflQ(Q, instrument.getWavelength(), 1.0-r_e*sld, d, sigma, return_int=return_int)
         # print 2.82e-5*sld
         # reload(slow_paratt)
         # R = slow_paratt.reflq_kin(Q, instrument.getWavelength(), 1.0 - 2.82e-5 * sld, d, sigma)
@@ -378,7 +379,7 @@ def specular_calcs(TwoThetaQz, sample, instrument, return_int=True):
         R=Paratt.ReflQ(Q, instrument.getWavelength(), 1.0-sld, d, sigma, return_int=return_int)
     # Ordinary Paratt but with magnetization
     elif ptype==instrument_string_choices['probe'][2] or ptype==2:
-        msld=2.645e-5*magn*dens*instrument.getWavelength()**2/2/pi
+        msld=muB_to_SL*magn*dens*instrument.getWavelength()**2/2/pi
         # Polarization uu or ++
         if pol==instrument_string_choices['pol'][0] or pol==0:
             R=Paratt.ReflQ(Q, instrument.getWavelength(), 1.0-sld-msld, d, sigma, return_int=return_int)
@@ -403,14 +404,18 @@ def specular_calcs(TwoThetaQz, sample, instrument, return_int=True):
         else:
             Q_ok=False
         if Buffer.parameters!=parameters or not Q_ok:
-            msld=2.645e-5*magn*dens*instrument.getWavelength()**2/2/pi
-            np=1.0-sld-msld
-            nm=1.0-sld+msld
-            Vp=(2*pi/instrument.getWavelength())**2*(1-np**2)
-            Vm=(2*pi/instrument.getWavelength())**2*(1-nm**2)
+            msld=muB_to_SL*magn*dens*instrument.getWavelength()**2/2/pi
+            # renormalize SLDs if ambient layer is not vacuum
+            if msld[-1]!=0. or sld[-1]!=0:
+                msld-=msld[-1]
+                sld-=sld[-1]
+            sld_p=sld+msld
+            sld_m=sld-msld
+            Vp=(2*pi/instrument.getWavelength())**2*(sld_p*(2.+sld_p))#(1-np**2) - better numerical accuracy
+            Vm=(2*pi/instrument.getWavelength())**2*(sld_m*(2.+sld_m))#(1-nm**2)
             (Ruu, Rdd, Rud, Rdu)=MatrixNeutron.Refl(Q, Vp, Vm, d, magn_ang, sigma, return_int=return_int)
-            Buffer.Ruu=Ruu;
-            Buffer.Rdd=Rdd;
+            Buffer.Ruu=Ruu
+            Buffer.Rdd=Rdd
             Buffer.Rud=Rud
             Buffer.parameters=parameters.copy()
             Buffer.TwoThetaQz=Q.copy()
@@ -451,7 +456,7 @@ def specular_calcs(TwoThetaQz, sample, instrument, return_int=True):
     elif ptype==instrument_string_choices['probe'][5] or ptype==5:
         wl=4*pi*sin(instrument.getIncangle()*pi/180)/Q
         sld=neutron_sld(abs_xs[:, newaxis], dens[:, newaxis], fb[:, newaxis], wl)
-        msld=2.645e-5*magn[:, newaxis]*dens[:, newaxis]*(4*pi*sin(instrument.getIncangle()*pi/180)/Q)**2/2/pi
+        msld=muB_to_SL*magn[:, newaxis]*dens[:, newaxis]*(4*pi*sin(instrument.getIncangle()*pi/180)/Q)**2/2/pi
         # polarization uu or ++
         if pol==instrument_string_choices['pol'][0] or pol==0:
             R=Paratt.Refl_nvary2(instrument.getIncangle()*ones(Q.shape),
@@ -538,7 +543,7 @@ def EnergySpecular(Energy, TwoThetaQz, sample, instrument):
     # Ordinary Paratt X-rays
     if ptype==instrument_string_choices['probe'][0] or ptype==0:
         # R = Paratt.ReflQ(Q,instrument.getWavelength(),1.0-2.82e-5*sld,d,sigma)
-        R=Paratt.Refl_nvary2(theta, wl, 1.0-2.82e-5*sld, d, sigma)
+        R=Paratt.Refl_nvary2(theta, wl, 1.0-r_e*sld, d, sigma)
     else:
         raise ValueError('The choice of probe is WRONG')
     # TODO: Fix corrections
@@ -581,13 +586,13 @@ def SLD_calculations(z, item, sample, inst):
     ptype=inst.getProbe()
     magnetic=False
     mag_sld=0
-    sld_unit='r_{e}/\AA^{3}'
+    sld_unit=r'r_{e}/\AA^{3}'
     if ptype==instrument_string_choices['probe'][0] or ptype==0:
         sld=dens*f
     elif ptype==instrument_string_choices['probe'][1] or ptype==1 or \
             ptype==instrument_string_choices['probe'][4] or ptype==4:
         sld=dens*(wl**2/2/pi*b-1.0J*abs_xs*wl/4/pi)/1e-6/(wl**2/2/pi)
-        sld_unit='10^{-6}\AA^{-2}'
+        sld_unit=r'10^{-6}\AA^{-2}'
     else:
         magnetic=True
         sld=dens*(wl**2/2/pi*b-1.0J*abs_xs*wl/4/pi)/1e-6/(wl**2/2/pi)
@@ -597,7 +602,7 @@ def SLD_calculations(z, item, sample, inst):
         mag_sld=2.645*magn*dens*10.
         mag_sld_x=mag_sld*cos(magn_ang)
         mag_sld_y=mag_sld*sin(magn_ang)
-        sld_unit='10^{-6}\AA^{-2}'
+        sld_unit=r'10^{-6}\AA^{-2}'
 
     d=array(parameters['d'], dtype=float64)
     d=d[1:-1]
